==> okapi-step-tokenization-1.43.0-sources.jar: net/sf/okapi/steps/tokenization/TokensAnnotation.java <==
/*===========================================================================
  Copyright (C) 2008-2012 by the Okapi Framework contributors
-----------------------------------------------------------------------------
  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
===========================================================================*/

package net.sf.okapi.steps.tokenization;

import net.sf.okapi.common.annotation.IAnnotation;

/**
 * Holds a list of {@link Token}
 */

public class TokensAnnotation implements IAnnotation {
	private Tokens tokens;

	public TokensAnnotation (Tokens tokens) {
		super();
		this.tokens = tokens;
	}

	public void setTokens (Tokens tokens) {
		this.tokens = tokens;
	}

	public Tokens getTokens () {
		return tokens;
	} 
	
	public Tokens getFilteredList (String... tokenTypes) {
		if (tokens == null) return getTokens(); // return all
		return tokens.getFilteredList(tokenTypes);
	}

	public void addTokens (Tokens tokens) {
		this.tokens.addAll(tokens);
	}
	
	@Override
	public String toString () {
		StringBuilder sb = new StringBuilder();
		for ( Token token : tokens ) {
			if ( sb.length()>0 ) sb.append(" ");
			sb.append(token.toString());
		}
		return sb.toString();
	}
}

==> okapi-step-tokenization-1.47.0-sources.jar: net/sf/okapi/steps/tokenization/TokensAnnotation.java <==
/*===========================================================================
  Copyright (C) 2008-2012 by the Okapi Framework contributors
-----------------------------------------------------------------------------
  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
===========================================================================*/

package net.sf.okapi.steps.tokenization;

import net.sf.okapi.common.annotation.IAnnotation;

/**
 * Holds a list of {@link Token}
 */

public class TokensAnnotation implements IAnnotation {
	private Tokens tokens;

	public TokensAnnotation (Tokens tokens) {
		super();
		this.tokens = tokens;
	}

	public void setTokens (Tokens tokens) {
		this.tokens = tokens;
	}

	public Tokens getTokens () {
		return tokens;
	} 
	
	public Tokens getFilteredList (String... tokenTypes) {
	    // return all tokens
		if (tokenTypes == null) return getTokens(); 
		// return only the listed tokenTypes
		return tokens.getFilteredList(tokenTypes);
	}

	public void addTokens (Tokens tokens) {
		this.tokens.addAll(tokens);
	}
	
	@Override
	public String toString () {
		StringBuilder sb = new StringBuilder();
		for ( Token token : tokens ) {
			if ( sb.length()>0 ) sb.append(" ");
			sb.append(token.toString());
		}
		return sb.toString();
	}
}
